@@ -10,7 +10,10 @@
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <strings.h>
 #include <syslog.h>
+#define __USE_BSD
 #include <unistd.h>
 
 #include <sys/poll.h>
@@ -55,6 +58,7 @@ void freeBuffer() {
 		free(buffer[x]);
 		x++;
 	}
+	free(buffer);
 }
 
 void cleanup(int exitcode) {
@@ -75,8 +79,8 @@ void cleanup(int exitcode) {
 void runDaemon(int sock) {
 	struct sockaddr_un addr;
 	int x,len,done=0;
-	socklen_t addrlen;
-	char *message;
+	socklen_t addrlen = sizeof(struct sockaddr_un);
+	char *message = NULL;
 	struct stat s1,s2;
 	struct pollfd pfds;
 
